﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;

using Infragistics.Controls.Menus;
using Infragistics.Controls.Grids;
using Infragistics.DragDrop;
using System.Collections.ObjectModel;

namespace DragAndDrop_Infra82
{
    public partial class MainPage : UserControl
    {
        private List<Person> _peopleCollection = null;
        public MainPage()
        {
            InitializeComponent();

            // grid row selection settings (read-only selection grid [so select entire row when clicking anywhere])
            igGridTransactions.SelectionSettings.ColumnSelection = SelectionType.None;
            igGridTransactions.SelectionSettings.RowSelection = SelectionType.Multiple;
            igGridTransactions.SelectionSettings.CellSelection = SelectionType.None;
            igGridTransactions.SelectionSettings.CellClickAction = CellSelectionAction.SelectRow;

            _peopleCollection = new List<Person>();

            this.LoadPeople();
            this.LoadTree();

            igGridTransactions.ItemsSource = _peopleCollection;

            // can't get to work, wanted to set each row as drag source...
            //this.SetDragSource();
        }

        private void LoadPeople()
        {
            _peopleCollection.Clear();

            _peopleCollection.Add(new Person() { First = "Ken", Last = "Smith" });
            _peopleCollection.Add(new Person() { First = "Don", Last = "Smith" });
            _peopleCollection.Add(new Person() { First = "Jeff", Last = "Smith" });
            _peopleCollection.Add(new Person() { First = "William", Last = "Smith" });
            _peopleCollection.Add(new Person() { First = "Tim", Last = "Smith" });
            _peopleCollection.Add(new Person() { First = "Colleen", Last = "Smith" });
            _peopleCollection.Add(new Person() { First = "Tom", Last = "Smith" });
            _peopleCollection.Add(new Person() { First = "Monica", Last = "Smith" });
        }

        private void LoadTree()
        {
            igTreeTransactions.Items.Clear();

            DropTarget dropTarget = null;

            XamTreeItem rootItem = new XamTreeItem() { Header = "Root", IsExpanded = true };

            XamTreeItem parentItem1 = new XamTreeItem() { Header = "Parent 1", IsExpanded = true };

            XamTreeItem leafItem1 = new XamTreeItem() { Header = "Leaf 1", IsExpanded = true };
            dropTarget = new DropTarget { IsDropTarget = true, DropChannels = new ObservableCollection<string>() { "test" } };
            DragDropManager.SetDropTarget(leafItem1, dropTarget);
            XamTreeItem leafItem2 = new XamTreeItem() { Header = "Leaf 2", IsExpanded = true };
            dropTarget = new DropTarget { IsDropTarget = true, DropChannels = new ObservableCollection<string>() { "test" } };
            DragDropManager.SetDropTarget(leafItem2, dropTarget);
            XamTreeItem leafItem3 = new XamTreeItem() { Header = "Leaf 3", IsExpanded = true };
            dropTarget = new DropTarget { IsDropTarget = true, DropChannels = new ObservableCollection<string>() { "test" } };
            DragDropManager.SetDropTarget(leafItem3, dropTarget);
            parentItem1.Items.Add(leafItem1);
            parentItem1.Items.Add(leafItem2);
            parentItem1.Items.Add(leafItem3);

            rootItem.Items.Add(parentItem1);

            igTreeTransactions.Items.Add(rootItem);
        }

        //private void SetDragSource()
        //{

        //    foreach (Infragistics.Controls.Grids.Row row in igGridTransactions.Rows)
        //    {
        //        DragSource dragSource = new DragSource { IsDraggable = true, DataObject = row };
        //        dragSource.Drop += new EventHandler<DropEventArgs>(dragSource_Drop);
        //        //DragDropManager.SetDragSource(row, dragSource);  ????
        //    }
        //}

        //void dragSource_Drop(object sender, DropEventArgs e)
        //{
        //    throw new NotImplementedException();
        //}

        private void DragSource_DragStart(object sender, Infragistics.DragDrop.DragDropStartEventArgs e)
        {
            // this will prevent multi-select if not possible
            //if (igGridTransactions.SelectionSettings.SelectedRows.Count > 1)
            //{
            //    e.Cancel = true;
            //    return;
            //}

            // disabling grid is only way I can figure out how to prevent rows from selecting while I'm dragging over them???
            igGridTransactions.IsEnabled = false;



            e.Data = igGridTransactions.SelectionSettings.SelectedRows;
        }

        private void DragSource_DragEnter(object sender, Infragistics.DragDrop.DragDropCancelEventArgs e)
        {
            // set status to drop target for debugging
            tbStatus.Text = e.DropTarget.ToString();

            // if its a tree, set activeitem so you can tell your selecting node
            XamTreeItem item = e.DropTarget as XamTreeItem;
            if (item != null)
                igTreeTransactions.ActiveItem = item;
        }

        private void DragSource_DragEnd(object sender, Infragistics.DragDrop.DragDropEventArgs e)
        {
            // re-enable grid and clear selected rows
            igGridTransactions.IsEnabled = true;

            // stuff I tried to return grid back to its normal state (non seemed to work)
            //VisualStateManager.GoToState(igGridTransactions, "Normal", false);
            //VisualStateManager.GoToState(igGridTransactions, "ReadOnly", false);
            //igGridTransactions.SelectionSettings.RowSelection = SelectionType.None;
            //igGridTransactions.SelectionSettings.RowSelection = SelectionType.Multiple;
            //igGridTransactions.SelectionSettings.SelectedRows.Clear();
            //VisualStateManager.GoToState(igTreeTransactions, "Active", false);
            //igTreeTransactions.Focus();
            //igGridTransactions.Focus();
        }

        private void DragSource_Drop(object sender, Infragistics.DragDrop.DropEventArgs e)
        {
            e.Data = null;
        }

        private void igGridTransactions_InitializeRow(object sender, InitializeRowEventArgs e)
        {
            // can't figure out how to set drag source to a grid row
            //DragSource dragSource = new DragSource { IsDraggable = true, DataObject = e.Row };
            //dragSource.Drop += new EventHandler<DropEventArgs>(dragSource_Drop);
            //DragDropManager.SetDragSource((object)e.Row, dragSource);
        }
    }

    public class Person
    {
        public string First { get; set; }
        public string Last { get; set; }

        public Person()
        {

        }

        public Person(string sFirst, string sLast)
        {
            First = sFirst;
            Last = sLast;
        }
    }
}
